pub struct StateHookSender(/* private fields */);Expand description
A wrapper for the sender that signals completion when dropped.
This type is intended to be used in combination with the evm executor statehook. This should trigger once the block has been executed (after) the last state update has been sent. This triggers the exit condition of the multi proof task.
Implementations
Sourceimpl StateHookSender
impl StateHookSender
Sourcepub const fn new(inner: CrossbeamSender<MultiProofMessage>) -> Self
pub const fn new(inner: CrossbeamSender<MultiProofMessage>) -> Self
Creates a new StateHookSender wrapping the given channel sender.
Methods from Deref<Target = CrossbeamSender<MultiProofMessage>>
pub fn try_send(&self, msg: T) -> Result<(), TrySendError<T>>
pub fn try_send(&self, msg: T) -> Result<(), TrySendError<T>>
Attempts to send a message into the channel without blocking.
This method will either send a message into the channel immediately or return an error if the channel is full or disconnected. The returned error contains the original message.
If called on a zero-capacity channel, this method will send the message only if there happens to be a receive operation on the other side of the channel at the same time.
Examples
use crossbeam_channel::{bounded, TrySendError};
let (s, r) = bounded(1);
assert_eq!(s.try_send(1), Ok(()));
assert_eq!(s.try_send(2), Err(TrySendError::Full(2)));
drop(r);
assert_eq!(s.try_send(3), Err(TrySendError::Disconnected(3)));pub fn send(&self, msg: T) -> Result<(), SendError<T>>
pub fn send(&self, msg: T) -> Result<(), SendError<T>>
Blocks the current thread until a message is sent or the channel is disconnected.
If the channel is full and not disconnected, this call will block until the send operation can proceed. If the channel becomes disconnected, this call will wake up and return an error. The returned error contains the original message.
If called on a zero-capacity channel, this method will wait for a receive operation to appear on the other side of the channel.
Examples
use std::thread;
use std::time::Duration;
use crossbeam_channel::{bounded, SendError};
let (s, r) = bounded(1);
assert_eq!(s.send(1), Ok(()));
thread::spawn(move || {
assert_eq!(r.recv(), Ok(1));
thread::sleep(Duration::from_secs(1));
drop(r);
});
assert_eq!(s.send(2), Ok(()));
assert_eq!(s.send(3), Err(SendError(3)));pub fn send_timeout(
&self,
msg: T,
timeout: Duration,
) -> Result<(), SendTimeoutError<T>>
pub fn send_timeout( &self, msg: T, timeout: Duration, ) -> Result<(), SendTimeoutError<T>>
Waits for a message to be sent into the channel, but only for a limited time.
If the channel is full and not disconnected, this call will block until the send operation can proceed or the operation times out. If the channel becomes disconnected, this call will wake up and return an error. The returned error contains the original message.
If called on a zero-capacity channel, this method will wait for a receive operation to appear on the other side of the channel.
Examples
use std::thread;
use std::time::Duration;
use crossbeam_channel::{bounded, SendTimeoutError};
let (s, r) = bounded(0);
thread::spawn(move || {
thread::sleep(Duration::from_secs(1));
assert_eq!(r.recv(), Ok(2));
drop(r);
});
assert_eq!(
s.send_timeout(1, Duration::from_millis(500)),
Err(SendTimeoutError::Timeout(1)),
);
assert_eq!(
s.send_timeout(2, Duration::from_secs(1)),
Ok(()),
);
assert_eq!(
s.send_timeout(3, Duration::from_millis(500)),
Err(SendTimeoutError::Disconnected(3)),
);pub fn send_deadline(
&self,
msg: T,
deadline: Instant,
) -> Result<(), SendTimeoutError<T>>
pub fn send_deadline( &self, msg: T, deadline: Instant, ) -> Result<(), SendTimeoutError<T>>
Waits for a message to be sent into the channel, but only until a given deadline.
If the channel is full and not disconnected, this call will block until the send operation can proceed or the operation times out. If the channel becomes disconnected, this call will wake up and return an error. The returned error contains the original message.
If called on a zero-capacity channel, this method will wait for a receive operation to appear on the other side of the channel.
Examples
use std::thread;
use std::time::{Duration, Instant};
use crossbeam_channel::{bounded, SendTimeoutError};
let (s, r) = bounded(0);
thread::spawn(move || {
thread::sleep(Duration::from_secs(1));
assert_eq!(r.recv(), Ok(2));
drop(r);
});
let now = Instant::now();
assert_eq!(
s.send_deadline(1, now + Duration::from_millis(500)),
Err(SendTimeoutError::Timeout(1)),
);
assert_eq!(
s.send_deadline(2, now + Duration::from_millis(1500)),
Ok(()),
);
assert_eq!(
s.send_deadline(3, now + Duration::from_millis(2000)),
Err(SendTimeoutError::Disconnected(3)),
);pub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if the channel is empty.
Note: Zero-capacity channels are always empty.
Examples
use crossbeam_channel::unbounded;
let (s, r) = unbounded();
assert!(s.is_empty());
s.send(0).unwrap();
assert!(!s.is_empty());pub fn is_full(&self) -> bool
pub fn is_full(&self) -> bool
Returns true if the channel is full.
Note: Zero-capacity channels are always full.
Examples
use crossbeam_channel::bounded;
let (s, r) = bounded(1);
assert!(!s.is_full());
s.send(0).unwrap();
assert!(s.is_full());pub fn len(&self) -> usize
pub fn len(&self) -> usize
Returns the number of messages in the channel.
Examples
use crossbeam_channel::unbounded;
let (s, r) = unbounded();
assert_eq!(s.len(), 0);
s.send(1).unwrap();
s.send(2).unwrap();
assert_eq!(s.len(), 2);pub fn capacity(&self) -> Option<usize>
pub fn capacity(&self) -> Option<usize>
If the channel is bounded, returns its capacity.
Examples
use crossbeam_channel::{bounded, unbounded};
let (s, _) = unbounded::<i32>();
assert_eq!(s.capacity(), None);
let (s, _) = bounded::<i32>(5);
assert_eq!(s.capacity(), Some(5));
let (s, _) = bounded::<i32>(0);
assert_eq!(s.capacity(), Some(0));pub fn same_channel(&self, other: &Sender<T>) -> bool
pub fn same_channel(&self, other: &Sender<T>) -> bool
Returns true if senders belong to the same channel.
Examples
use crossbeam_channel::unbounded;
let (s, _) = unbounded::<usize>();
let s2 = s.clone();
assert!(s.same_channel(&s2));
let (s3, _) = unbounded();
assert!(!s.same_channel(&s3));Trait Implementations
Sourceimpl Debug for StateHookSender
impl Debug for StateHookSender
Sourceimpl Deref for StateHookSender
impl Deref for StateHookSender