pub struct StateRootHandle { /* private fields */ }Expand description
Handle to a background state root computation task.
Unlike PayloadHandle, this does not include transaction iteration or cache prewarming.
It only provides access to the state root computation via Self::state_hook and
Self::state_root.
Created by PayloadProcessor::spawn_state_root.
Implementations
Sourceimpl StateRootHandle
impl StateRootHandle
Sourcepub const fn new(
to_multi_proof: CrossbeamSender<MultiProofMessage>,
state_root_rx: Receiver<Result<StateRootComputeOutcome, ParallelStateRootError>>,
) -> Self
pub const fn new( to_multi_proof: CrossbeamSender<MultiProofMessage>, state_root_rx: Receiver<Result<StateRootComputeOutcome, ParallelStateRootError>>, ) -> Self
Creates a new state root handle.
Sourcepub fn state_hook(&self) -> impl OnStateHook
pub fn state_hook(&self) -> impl OnStateHook
Returns a state hook that streams state updates to the background state root task.
The hook must be dropped after execution completes to signal the end of state updates.
Sourcepub fn state_root(
&mut self,
) -> Result<StateRootComputeOutcome, ParallelStateRootError>
pub fn state_root( &mut self, ) -> Result<StateRootComputeOutcome, ParallelStateRootError>
Sourcepub const fn take_state_root_rx(
&mut self,
) -> Receiver<Result<StateRootComputeOutcome, ParallelStateRootError>>
pub const fn take_state_root_rx( &mut self, ) -> Receiver<Result<StateRootComputeOutcome, ParallelStateRootError>>
Takes the state root receiver for use with custom waiting logic (e.g., timeouts).
Panics
If called more than once.