pub struct EngineApiTreeState<N: NodePrimitives> { /* private fields */ }Expand description
Tracks the state of the engine api internals.
This type is not shareable.
Implementations
Sourceimpl<N: NodePrimitives> EngineApiTreeState<N>
impl<N: NodePrimitives> EngineApiTreeState<N>
Sourcepub const fn tree_state(&self) -> &TreeState<N>
pub const fn tree_state(&self) -> &TreeState<N>
Returns a reference to the tree state.
Sourcepub const fn pending_sparse_trie_prune(&self) -> bool
pub const fn pending_sparse_trie_prune(&self) -> bool
Returns whether sparse trie pruning is pending.
Sourcepub const fn set_pending_sparse_trie_prune(&mut self, pending: bool)
pub const fn set_pending_sparse_trie_prune(&mut self, pending: bool)
Sets whether sparse trie pruning is pending for the next sparse trie task.
Sourcepub fn take_sparse_trie_prune_blocks(
&mut self,
parent_hash: B256,
) -> Option<Vec<ExecutedBlock<N>>>
pub fn take_sparse_trie_prune_blocks( &mut self, parent_hash: B256, ) -> Option<Vec<ExecutedBlock<N>>>
Takes a pending sparse trie prune request, if any, and snapshots the in-memory parent chain
ending at parent_hash.
None means no prune request is pending. Some(Vec::new()) means a prune was requested,
but no in-memory parent-chain blocks were found for the parent hash; the sparse trie task
should still prune using the current block’s changed paths.
Sourcepub fn has_invalid_header(&mut self, hash: &B256) -> bool
pub fn has_invalid_header(&mut self, hash: &B256) -> bool
Returns true if the block has been marked as invalid.