pub trait WaitForCaches {
// Required method
fn wait_for_caches(&self) -> CacheWaitDurations;
}Expand description
Trait for types that can wait for caches to become available.
Used by reth_newPayload to wait for cache updates before starting payload processing.
Removed execution-cache allocations may still be destroyed concurrently after unlocking.
Required Methods
Sourcefn wait_for_caches(&self) -> CacheWaitDurations
fn wait_for_caches(&self) -> CacheWaitDurations
Waits for cache updates to complete.
Returns the time spent waiting for each cache separately.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".