WaitForCaches

Trait WaitForCaches 

pub trait WaitForCaches {
    // Required method
    fn wait_for_caches(&self) -> CacheWaitDurations;
}
Trait for types that can wait for caches to become available.

This is used by reth_newPayload endpoint to ensure that payload processing waits for any ongoing operations to complete before starting.

Required Methods

fn wait_for_caches(&self) -> CacheWaitDurations

Waits for cache updates to complete.

Returns the time spent waiting for each cache separately.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Evm> WaitForCaches for PayloadProcessor<Evm>
where Evm: ConfigureEvm,

Source

impl<P, Evm, V> WaitForCaches for BasicEngineValidator<P, Evm, V>
where Evm: ConfigureEvm,