pub trait WaitForCaches {
// Required method
fn wait_for_caches(&self) -> CacheWaitDurations;
}Expand description
Trait for types that can wait for caches to become available.
This is used by reth_newPayload endpoint to ensure that payload processing
waits for any ongoing operations to complete before starting.
Required Methods
Sourcefn wait_for_caches(&self) -> CacheWaitDurations
fn wait_for_caches(&self) -> CacheWaitDurations
Waits for cache updates to complete.
Returns the time spent waiting for each cache separately.